@@ -24,29 +24,29 @@
 #ifndef _E_TREE_SCROLLED_H_
 #define _E_TREE_SCROLLED_H_
 
-#include <gal/widgets/e-scroll-frame.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gal/e-table/e-tree-model.h>
 #include <gal/e-table/e-tree.h>
 
 G_BEGIN_DECLS
 
 #define E_TREE_SCROLLED_TYPE        (e_tree_scrolled_get_type ())
-#define E_TREE_SCROLLED(o)          (GTK_CHECK_CAST ((o), E_TREE_SCROLLED_TYPE, ETreeScrolled))
-#define E_TREE_SCROLLED_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TREE_SCROLLED_TYPE, ETreeScrolledClass))
-#define E_IS_TREE_SCROLLED(o)       (GTK_CHECK_TYPE ((o), E_TREE_SCROLLED_TYPE))
-#define E_IS_TREE_SCROLLED_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TREE_SCROLLED_TYPE))
+#define E_TREE_SCROLLED(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TREE_SCROLLED_TYPE, ETreeScrolled))
+#define E_TREE_SCROLLED_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_TREE_SCROLLED_TYPE, ETreeScrolledClass))
+#define E_IS_TREE_SCROLLED(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_TREE_SCROLLED_TYPE))
+#define E_IS_TREE_SCROLLED_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_TREE_SCROLLED_TYPE))
 
 typedef struct {
-	EScrollFrame parent;
+	GtkScrolledWindow parent;
 
 	ETree *tree;
 } ETreeScrolled;
 
 typedef struct {
-	EScrollFrameClass parent_class;
+	GtkScrolledWindowClass parent_class;
 } ETreeScrolledClass;
 
-GtkType         e_tree_scrolled_get_type                  (void);
+GType           e_tree_scrolled_get_type                  (void);
 
 ETreeScrolled *e_tree_scrolled_construct                 (ETreeScrolled *ets,
 							  ETreeModel    *etm,
@@ -73,4 +73,3 @@ ETree         *e_tree_scrolled_get_tree                 (ETreeScrolled *ets);
 G_END_DECLS
 
 #endif /* _E_TREE_SCROLLED_H_ */
-
